@@ -1,14 +1,10 @@
-import skopt
-from skopt.space import Real, Categorical, Integer
-
-from hpogrid.search_space.base_space import BaseSpace
+from .base_space import BaseSpace
 
 class SkOptSpace(BaseSpace):
 
-    def __init__(self, search_space = None):
+    def __init__(self, search_space=None):
         self.library = 'skopt'
         super().__init__(search_space)    
-        
 
     def reset_space(self):
         self.search_space = []
@@ -18,19 +14,24 @@ class SkOptSpace(BaseSpace):
 
     def categorical(self, label, categories, grid_search = False):
         if grid_search != False:
-            raise ValueError('{} does not allow grid search'.format(self.library))
+            raise ValueError(f'{self.library} does not allow grid search')
+        from skopt.space import Categorical
         return Categorical(name=label, categories=categories)
 
     def uniformint(self, label, low, high):
+        from skopt.space import Integer
         return Integer(name=label, low=low, high=high, prior="uniform")
 
     def uniform(self, label, low, high):
+        from skopt.space import Real
         return Real(name=label, low=low, high=high, prior='uniform')
 
     def loguniform(self, label, low, high, base=10):
+        from skopt.space import Real
         return Real(name=label, low=low, high=high, prior='log-uniform', base=base)
 
     def loguniformint(self, label, low, high, base=10):
+        from skopt.space import Integer
         return Integer(name=label, low=low, high=high, prior="log-uniform", base=base)
 
     def fixed(self, label, value):
